Module regex

Module regex 

Functions

build_case_insensitive_regex
Build a case-insensitive regex from a pattern string with DOTALL flag Includes timeout protection against ReDoS attacks
build_regex
Build a regex from a pattern string with DOTALL flag Includes timeout protection against ReDoS attacks
build_search_regex
Build a search regex (without anchors) with optional case sensitivity Includes timeout protection against ReDoS attacks
prepare_search_regex
Remove anchors and flags from a regex string for search operations Returns a string slice or owned string as needed