pub fn build_regex(pattern: &str) -> Result<Regex, FormatParseError>Expand description
Build a regex from a pattern string with DOTALL flag Includes timeout protection against ReDoS attacks
pub fn build_regex(pattern: &str) -> Result<Regex, FormatParseError>Build a regex from a pattern string with DOTALL flag Includes timeout protection against ReDoS attacks