Backslash–newline continuations in matched input for :ml / :blk fields (GitHub issue #80).
Same rules as format pattern continuations (issue #68): a run of k backslashes immediately
before a line ending (\n or \r\n) — if k is odd, the line continues (the last backslash
plus the line break are removed, and floor((k-1)/2) literal backslashes are kept); if k is
even, k/2 literal backslashes are kept and the line break is preserved. After a continuation,
ASCII spaces and tabs at the start of the next physical line are stripped.
Functions
- normalize_
input_ line_ continuations - Fold backslash line continuations in captured multiline / indent-block text.